# Turnstone Contributor License Agreement

Thank you for your interest in contributing to Turnstone. This Contributor
License Agreement ("Agreement") is between you ("Contributor") and Patrick
Buckley ("Maintainer"), and applies to all Contributions submitted to the
Turnstone project at https://github.com/turnstonelabs/turnstone.

By submitting a Contribution, you agree to the following terms:

## 1. Definitions

"Contribution" means any original work of authorship, including modifications
or additions to existing work, that you submit to the project via pull request,
issue, or any other means.

## 2. Grant of Copyright License

You grant the Maintainer a perpetual, worldwide, non-exclusive, royalty-free,
irrevocable copyright license to reproduce, prepare derivative works of,
publicly display, publicly perform, sublicense, and distribute your
Contributions and any derivative works thereof under any license, including
proprietary licenses.

## 3. Grant of Patent License

You grant the Maintainer a perpetual, worldwide, non-exclusive, royalty-free,
irrevocable patent license to make, have made, use, offer to sell, sell,
import, and otherwise transfer your Contributions, where such license applies
only to patent claims licensable by you that are necessarily infringed by your
Contributions alone or in combination with the project.

## 4. Representations

You represent that:

- Each Contribution is your original creation and you have the legal right to
  grant the above licenses.
- Your Contribution does not violate any third party's intellectual property or
  other rights.
- If your employer has rights to intellectual property that you create, you have
  received permission to make the Contribution on behalf of that employer, or
  your employer has waived such rights.

## 5. No Obligation

You understand that the decision to include your Contribution in the project is
entirely at the Maintainer's discretion. This Agreement does not obligate the
Maintainer to use or incorporate your Contribution.

## Signing

By submitting a pull request to the Turnstone repository, and commenting
"I have read the CLA and I agree to its terms," you indicate your acceptance
of this Agreement.
